@@ -208,8 +208,18 @@ createWithMetadataAndFile <- function (metadata, file, strict=TRUE, cleanup=TRUE
     if (!strict) {
         batches_url <- paste0(batches_url, "?strict=0")
     }
-    batch <- try(crPOST(batches_url,
-        body=list(file=httr::upload_file(file))))
+    if (substr(file, 1, 5) == "s3://") {
+        ## S3 upload
+        batch <- try(crPOST(batches_url, body=toJSON(list(
+            element="shoji:entity",
+            body=list(
+                url=file
+            )))))
+    } else {
+        ## Local file. Send it as file upload
+        batch <- try(crPOST(batches_url,
+            body=list(file=httr::upload_file(file))))
+    }
     if (is.error(batch) && cleanup) {
         delete(ds, confirm=FALSE)
         rethrow(batch)
