@@ -139,7 +139,6 @@ urlizeUserEmails <- function (x) {
 setMethod("[[<-", c("MemberCatalog", "character", "missing", "NULL"),
     function (x, i, j, value) {
         ## Remove the specified user from the catalog
-        i <- urlizeUserEmails(i)
         payload <- sapply(i, function (z) NULL, simplify=FALSE)
         crPATCH(self(x), body=toJSON(payload))
         return(refresh(x))
@@ -157,10 +156,8 @@ setMethod("members<-", c("CrunchTeam", "MemberCatalog"), function (x, value) {
 ##' @rdname teams
 ##' @export
 setMethod("members<-", c("CrunchTeam", "character"), function (x, value) {
-    ## value can be URL or email
-    value <- urlizeUserEmails(value)
     payload <- sapply(value, 
-        function (z) structure(list(), .Names=character(0)),
+        function (z) emptyObject(),
         simplify=FALSE)
     crPATCH(self(members(x)), body=toJSON(payload))
     return(refresh(x))
@@ -168,7 +165,7 @@ setMethod("members<-", c("CrunchTeam", "character"), function (x, value) {
 
 ##' @rdname delete
 ##' @export
-setMethod("delete", "CrunchTeam", function (x, confirm=interactive(), ...) {
+setMethod("delete", "CrunchTeam", function (x, confirm=requireConsent(), ...) {
     prompt <- paste0("Really delete team ", dQuote(name(x)), "? ",
         "This cannot be undone.")
     if (confirm && !askForPermission(prompt)) {
