@@ -21,6 +21,18 @@
         out <- structure(list(zcl(typeof(value, variable))),
             .Names=tuple(variable)$id)
     }
+    
+    ## Check for missingness and replace the NAs with special values
+    out <- lapply(out, function (x) {
+        if ("column" %in% names(x)) {
+            missings <- is.na(x$column)
+            if (any(missings)) {
+                x$column <- as.list(x$column)
+                x$column[missings] <- rep(list(.no.data.value(type(variable))), sum(missings))
+            }
+        }
+        return(x)
+    })
     return(out)
 }
 
@@ -53,7 +65,13 @@ NULL
 ##' @rdname variable-update
 ##' @export
 setMethod("[<-", c("CrunchVariable", "ANY", "missing", "ANY"), .backstopUpdate)
-    
+
+##' @rdname variable-update
+##' @export
+setMethod("[<-", c("CrunchVariable", "ANY", "missing", "NULL"), 
+    function (x, i, j, value) return(NULL))
+
+
 .sigs <- list(
     c("TextVariable", "character"),
     c("NumericVariable", "numeric"),
@@ -68,10 +86,10 @@ setMethod("[<-", c("CrunchVariable", "ANY", "missing", "ANY"), .backstopUpdate)
     return(x)
 }
 
-for (i in seq_along(.sigs)) {
-    setMethod("[<-", c(.sigs[[i]][1], "ANY", "missing", .sigs[[i]][2]),
-        .var.updater)
-}
+# for (i in seq_along(.sigs)) {
+#     setMethod("[<-", c(.sigs[[i]][1], "ANY", "missing", .sigs[[i]][2]),
+#         .var.updater)
+# }
 
 # for (i in seq_along(.sigs)) {
 #         cat('
@@ -129,13 +147,9 @@ setMethod("[<-", c("CrunchVariable", "CrunchExpr", "missing", "CrunchExpr"),
                 serialPaste(invalids), ifelse(plural, " are ", " is "),
                 "not present in the category ids of variable ", dQuote(name(x))))
         }
-        # if (add.no.data) {
-        #     newcats <- categories(x)
-        #     newcats[[length(newcats) + 1]] <- Category(.no.data)
-        #     print(class(newcats))
-        #     print(newcats)
-        #     categories(x) <- newcats
-        # }
+        if (add.no.data) {
+            categories(x)[[length(categories(x)) + 1]] <- Category(data=.no.data)
+        }
         out <- .updateVariable(x, value, filter=.dispatchFilter(i))
         return(x)
     },
@@ -143,6 +157,8 @@ setMethod("[<-", c("CrunchVariable", "CrunchExpr", "missing", "CrunchExpr"),
         if (missing(i)) i <- NULL
         value[is.na(value)] <- "No Data"
         invalids <- setdiff(value, names(categories(x)))
+        add.no.data <- "No Data" %in% invalids
+        invalids <- setdiff(invalids, "No Data")
         if (length(invalids)) {
             plural <- length(invalids) > 1
             halt(paste0("Input value", ifelse(plural, "s ", " "),
@@ -150,6 +166,9 @@ setMethod("[<-", c("CrunchVariable", "CrunchExpr", "missing", "CrunchExpr"),
                 "not present in the category names of variable ",
                 dQuote(name(x))))
         }
+        if (add.no.data) {
+            categories(x)[[length(categories(x)) + 1]] <- Category(data=.no.data)
+        }
         value <- n2i(value, categories(x))
         out <- .updateVariable(x, value, filter=.dispatchFilter(i))
         return(x)
@@ -161,11 +180,11 @@ setMethod("[<-", c("CrunchVariable", "CrunchExpr", "missing", "CrunchExpr"),
     }
 )
 
-for (i in c("CategoricalVariable", "CategoricalArrayVariable")) {
-    for (j in c("numeric", "character", "factor")) {
-        setMethod("[<-", c(i, "ANY", "missing", j), .categorical.update[[j]])
-    }
-}
+# for (i in c("CategoricalVariable", "CategoricalArrayVariable")) {
+#     for (j in c("numeric", "character", "factor")) {
+#         setMethod("[<-", c(i, "ANY", "missing", j), .categorical.update[[j]])
+#     }
+# }
 
 # for (i in c("CategoricalVariable", "CategoricalArrayVariable")) {
 #     for (j in c("numeric", "character", "factor")) {
@@ -195,24 +214,40 @@ setMethod("[<-", c("CategoricalArrayVariable", "ANY", "missing", "character"), .
 ##' @export
 setMethod("[<-", c("CategoricalArrayVariable", "ANY", "missing", "factor"), .categorical.update[["factor"]])
 
-# setMethod("[<-", c("CrunchVariable", "ANY", "missing", "logical"),
-#     function (x, i, j, value) {
-#           ## For assigning NA
-#         cal <- match.call()
-#         print(cal)
-#         if (all(is.na(value))) {
-#             value <- ifelse(is.Text(x), NA_character_, NA_integer_)
-#         } else {
-#             halt("Cannot update CrunchVariable with logical")
-#         }
-#         if (missing(i)) i <- NULL
-#         i <- zcl(.dispatchFilter(i))
-#         
-#         x@fragments$missing_rules
-#         
-#         x[i] <- value
-#         return(x)
-#     })
+##' @rdname variable-update
+##' @export
+setMethod("[<-", c("CrunchVariable", "ANY", "missing", "logical"),
+    function (x, i, j, value) {
+        ## For assigning NA
+        if (all(is.na(value))) {
+            value <- .no.data.value(type(x), add.type=TRUE)
+        } else {
+            ## halt()
+            .backstopUpdate(x, i, j, value)
+        }
+        
+        ## Datetime not yet supported, apparently
+        if (is.Datetime(x)) {
+            .backstopUpdate(x, i, j, value)
+        } else if (is.Categorical(x) || is.CA(x) || is.MR(x)) {
+            return(.categorical.update[["numeric"]](x, i, j, value))
+        }
+        if (missing(i)) i <- NULL
+        out <- .updateVariable(x, value, filter=.dispatchFilter(i))
+        return(x)
+    })
+
+.no.data.value <- function (x, add.type=FALSE) {
+    if (x %in% c("categorical", "multiple_response", "categorical_array")) {
+        return(-1L)
+    } else {
+        out <- list(`?`=-1L)
+        if (add.type) {
+            out <- list(value=out, type=list(class=x))
+        }
+        return(out)
+    }
+}
 
 ##' @rdname variable-update
 ##' @export
