@@ -10,14 +10,15 @@ load("getting-started.RData")
 #  load("economist.RData")
 #  dim(df)
 
-## ------------------------------------------------------------------------
-dim(ds)
+## ---- echo=FALSE---------------------------------------------------------
+dim.ds
 
 ## ---- eval=FALSE---------------------------------------------------------
 #  ds <- newDataset(df, name="Economist/YouGov Weekly Survey")
+#  dim(ds)
 
-## ------------------------------------------------------------------------
-dim(ds)
+## ---- echo=FALSE---------------------------------------------------------
+dim.ds
 
 ## ---- eval=FALSE---------------------------------------------------------
 #  listDatasets()
