@@ -11,6 +11,18 @@ test_that("login checks for email and password before POSTing", {
         "Must supply a password")
 })
 
+with(fake.HTTP, {
+    test_that("Jupyter helper sets up env", {
+        with(reset.option("httr_config"), {
+            jupyterLogin("test_token")
+            cfg <- getOption("httr_config")
+            expect_identical(cfg$options$cookie, "token=test_token")
+            expect_true(grepl("jupyter.crunch.io", cfg$headers[["user-agent"]]))
+            expect_true(grepl("rcrunch", cfg$headers[["user-agent"]]))
+        })
+    })
+})
+
 if (run.integration.tests) {
     test_that("login works if crunch is running", {
         deleteSessionInfo()
