@@ -35,13 +35,24 @@ if (run.integration.tests) {
                     array(c(2, 0, 1, 0, 1, 0, 0, 1), dim=c(2L, 4L),
                         dimnames=list(v4=c("B", "C"),
                         MR=c("mr_1", "mr_2", "mr_3", "<NA>"))))
+                
+                kube@useNA <- "always"
+                expect_equivalent(as.array(kube),
+                    array(c(2, 0, 0,
+                            1, 0, 0,
+                            1, 0, 0,
+                            0, 1, 0), dim=c(3L, 4L),
+                        dimnames=list(v4=c("B", "C", "No Data"),
+                        MR=c("mr_1", "mr_2", "mr_3", "<NA>"))))
             })
             
-            test_that("prop.table on univariate MR", {
-                c1 <- crtabs(~ MR, data=mrds)
+            c1 <- crtabs(~ MR, data=mrds)
+            test_that("prop.table on univariate MR without NAs", {
                 expect_equivalent(prop.table(c1),
                     array(c(2/3, 1/3, 1/3), dim=c(3L),
                         dimnames=list(MR=c("mr_1", "mr_2", "mr_3"))))
+            })
+            test_that("prop.table on univariate MR, useNA=always", {
                 c2 <- c1
                 c2@useNA <- "always"
                 expect_equivalent(prop.table(c2),
@@ -49,12 +60,12 @@ if (run.integration.tests) {
                         dimnames=list(MR=c("mr_1", "mr_2", "mr_3", "<NA>"))))
             })
             
-            test_that("prop.table on bivariate with MR", {
-                c1 <- crtabs(~ v5 + MR, data=mrds)
-                #    MR
-                # v5  mr_1 mr_2 mr_3
-                #   A    1    0    0
-                #   B    1    1    1
+            c1 <- crtabs(~ v5 + MR, data=mrds)
+            #    MR
+            # v5  mr_1 mr_2 mr_3
+            #   A    1    0    0
+            #   B    1    1    1
+            test_that("prop.table on bivariate with MR, no NAs", {
                 expect_equivalent(as.array(c1),
                     array(c(1, 1, 0, 1, 0, 1), dim=c(2L, 3L),
                         dimnames=list(v5=c("A", "B"),
@@ -76,27 +87,35 @@ if (run.integration.tests) {
                     array(c(.5, .5, 0, 1, 0, 1), dim=c(2L, 3L),
                         dimnames=list(v5=c("A", "B"),
                         MR=c("mr_1", "mr_2", "mr_3"))))
-                c2 <- c1
-                c2@useNA <- "ifany"
-                #    MR
-                # v5  mr_1 mr_2 mr_3 <NA>
-                #   A    1    0    0    0
-                #   B    1    1    1    1
+            })
+            c2 <- c1
+            c2@useNA <- "ifany"
+            #    MR
+            # v5  mr_1 mr_2 mr_3 <NA>
+            #   A    1    0    0    0
+            #   B    1    1    1    1
+            test_that("prop.table on bivariate with MR, margin=NULL, useNA=ifany", {
                 expect_equivalent(as.array(c2),
                     array(c(1, 1, 0, 1, 0, 1, 0, 1), dim=c(2L, 4L),
                         dimnames=list(v5=c("A", "B"),
                         MR=c("mr_1", "mr_2", "mr_3", "<NA>"))))
+                
+                ## Sweep the whole table
                 expect_equivalent(margin.table(c2), 4)
                 expect_equivalent(prop.table(c2),
                     array(c(1, 1, 0, 1, 0, 1, 0, 1)/4, dim=c(2L, 4L),
                         dimnames=list(v5=c("A", "B"),
                         MR=c("mr_1", "mr_2", "mr_3", "<NA>"))))
+            })
+            test_that("prop.table on bivariate with MR, margin=1, useNA=ifany", {
                 expect_equivalent(margin.table(c2, 1),
                     as.array(c(2, 2)))
                 expect_equivalent(prop.table(c2, margin=1),
                     array(c(.5, .5, 0, .5, 0, .5, 0, .5), dim=c(2L, 4L),
                         dimnames=list(v5=c("A", "B"),
                         MR=c("mr_1", "mr_2", "mr_3", "<NA>"))))
+            })
+            test_that("prop.table on bivariate with MR, margin=2, useNA=ifany", {
                 expect_equivalent(margin.table(c2, 2),
                     as.array(c(2, 1, 1, 1)))
                 expect_equivalent(prop.table(c2, margin=2),
@@ -121,6 +140,15 @@ if (run.integration.tests) {
             test_that("prop.table on univariate CA", {
                 
             })
+            
+            test_that("accessing array subvariables", {
+                kube <- crtabs(~ CA$mr_1 + CA$mr_2, data=mrds, useNA="ifany")
+                expect_equivalent(as.array(kube), 
+                    array(c(1, 1, 0, 0, 1, 0, 0, 0, 1),
+                    dim=c(3L, 3L),
+                    dimnames=list(mr_1=c("0.0", "1.0", "No Data"),
+                        mr_2=c("0.0", "1.0", "No Data"))))
+            })
         })
     })
 }
\ No newline at end of file
