@@ -81,6 +81,10 @@ with(fake.HTTP, {
         expect_identical(types(varcat)[1:3],
             c("categorical", "numeric", "datetime"))
     })
+    
+    test_that("show method", {
+        expect_true(is.character(capture.output(print(varcat))))
+    })
 })
 
 if (run.integration.tests) {
